@@ -509,6 +509,8 @@ enum {
   SPVM_OPCODE_C_ID_ENABLE_OPTIONS,
   SPVM_OPCODE_C_ID_DISABLE_OPTIONS,
   SPVM_OPCODE_C_ID_IS_OPTIONS,
+  SPVM_OPCODE_C_ID_EXISTS,
+  SPVM_OPCODE_C_ID_DELETE,
 };
 
 // An operation code is 128 bits
