@@ -494,6 +494,7 @@ void SPVM_COMPILER_use_default_loaded_classes(SPVM_COMPILER* compiler) {
   SPVM_COMPILER_use(compiler, "SPVM", "SPVM", 0);
   SPVM_COMPILER_use(compiler, "Error::MethodCallNotPermitted", "Error::MethodCallNotPermitted", 0);
   SPVM_COMPILER_use(compiler, "Stringable", "Stringable", 0);
+  SPVM_COMPILER_use(compiler, "Countable", "Countable", 0);
 }
 
 void SPVM_COMPILER_set_default_loaded_class_files(SPVM_COMPILER* compiler) {
@@ -626,6 +627,14 @@ void SPVM_COMPILER_set_default_loaded_class_files(SPVM_COMPILER* compiler) {
     SPVM_COMPILER_set_class_file_with_members(compiler, class_name, rel_file, content);
   }
   
+  // Add Countable class file
+  {
+    const char* class_name = "Countable";
+    const char* rel_file = "Countable.spvm";
+    const char* content = "class Countable : interface_t {\n  version_from SPVM;\n  required method length : int ();\n}";
+    SPVM_COMPILER_set_class_file_with_members(compiler, class_name, rel_file, content);
+  }
+  
 }
 
 void SPVM_COMPILER_set_class_file_with_members(SPVM_COMPILER* compiler, const char* class_name, const char* rel_file, const char* content) {
