@@ -180,7 +180,7 @@ C<switch> statement is a conditional statement with the following syntax.
 
 The L<integer promotional conversion|SPVM::Document::Language::Operators/"Integer Promotional Conversion"> is performed on the condition I<CONDITION>.
 
-The operand of the case statement I<CASEn> must be a L<character literal|SPVM::Document::Language::Tokenization/"Character Literal">, an L<integer literal|SPVM::Document::Language::Tokenization/"Integer Literals"> and an L<inline-expaned class method call to get an enumeration value|SPVM::Document::Language::Class/"Inline Expansion of Method Call to Get an Enuemration Value">.
+The operand of case statement I<CASEn> must be a L<character literal|SPVM::Document::Language::Tokenization/"Character Literal">, an L<integer literal|SPVM::Document::Language::Tokenization/"Integer Literals"> and an L<inline-expaned class method call to get an enumeration value|SPVM::Document::Language::Class/"Inline Expansion of Method Call to Get an Enuemration Value">.
 
 If I<CASEn> is a L<character literal|SPVM::Document::Language::Tokenization/"Character Literal">, the value is converted to int type at compile-time.
 
@@ -388,7 +388,7 @@ Examples:
 
   my $i = 0;
   
-  # beginning of the while statement
+  # beginning of while statement
   while ($i < 5) {
   
     if ($i == 3) {
@@ -415,7 +415,7 @@ Examples:
     # last statement makes the program jump to the end fo the current while statement.
     last;
   }
-  # end fo the while statement
+  # end fo while statement
 
 =head3 for Statement
 
@@ -640,35 +640,6 @@ Examples:
     warn "Warning: Can't load MyClass";
   }
 
-=head2 copy_fields Statement
-
-The C<copy_fields> statement copies fields.
-
-  copy_fields DIST_OPERAND, SRC_OPERAND, TYPE;
-
-The type of I<TYPE> must be a class type.
-
-The copy_fields statement copies every field from I<SRC_OPERAND> to I<DIST_OPERAND> using all the field names defined in I<TYPE> class.
-
-For example, if the field names defined in I<TYPE> class are C<x>, C<y>, and C<z>, then copy_field statement is expanded to the following codes:
-
-  DIST_OPERAND->{x} = SRC_OPERAND->{x};
-  DIST_OPERAND->{y} = SRC_OPERAND->{y};
-  DIST_OPERAND->{z} = SRC_OPERAND->{z};
-
-Compilation Errors:
-
-The type of I<TYPE> must be a class type. Otherwise, a compilation error occurs. 
-
-Examples:
-  
-  # Exampels of copy_fields statement
-  my $object = MyClass->new;
-  
-  my $object_child = MyClass::Child->new;
-  
-  copy_fields $object_child, $object, MyClass;
-
 =head1 See Also
 
 =over 2
